Module cache

Module cache 

Re-exports

pub use crate::platform::get_current_architecture;
pub use crate::platform::get_current_os;
pub use crate::platform::get_current_platform;

Structs

DistributionCache
MetadataCache
PlatformFilter
SearchResult

Enums

VersionSearchType

Functions

convert_api_to_cache
Convert API metadata response to cache format
convert_package_to_jdk_metadata
Convert an API package to JDK metadata
fetch_and_cache_distribution
Fetch metadata for a specific distribution and update the cache
fetch_and_cache_metadata_with_progress
Fetch metadata from API and cache it with progress reporting
fetch_package_checksum
Fetch checksum for a specific JDK package (uses SilentProgress internally)
get_metadata
Get metadata with optional version check Get metadata with optional version check (uses SilentProgress internally)
load_cache
Load metadata cache from a file
parse_architecture_from_filename
Parse architecture from filename patterns
save_cache
Save metadata cache to a file