pub struct PackageCoordinate { /* private fields */ }Expand description
Coordinate that uniquely identifies a package for lock scoping.
Implementations
Sourceimpl PackageCoordinate
impl PackageCoordinate
Sourcepub fn new<S: Into<String>>(
distribution: S,
major_version: u32,
package_kind: PackageKind,
) -> Self
pub fn new<S: Into<String>>( distribution: S, major_version: u32, package_kind: PackageKind, ) -> Self
Creates a new coordinate with the required fields.
pub fn distribution(&self) -> &str
pub fn major_version(&self) -> u32
pub fn package_kind(&self) -> PackageKind
pub fn architecture(&self) -> Option<&str>
pub fn operating_system(&self) -> Option<&str>
pub fn libc_variant(&self) -> Option<&str>
pub fn javafx_bundled(&self) -> bool
pub fn with_architecture<S: Into<String>>(self, architecture: Option<S>) -> Self
pub fn with_operating_system<S: Into<String>>( self, operating_system: Option<S>, ) -> Self
pub fn with_libc_variant<S: Into<String>>(self, libc_variant: Option<S>) -> Self
pub fn with_javafx(self, javafx_bundled: bool) -> Self
Sourcepub fn slug(&self) -> String
pub fn slug(&self) -> String
Generates a deterministic slug suitable for filesystem lock names.
Sourcepub fn try_from_package(package: &Package) -> Result<Self>
pub fn try_from_package(package: &Package) -> Result<Self>
Attempts to build a coordinate from a metadata package definition.