Re-exports
pub use crate::platform::get_current_architecture;pub use crate::platform::get_current_os;pub use crate::platform::get_current_platform;
Structs
Enums
Functions
- convert_
api_ to_ cache - Convert API metadata response to cache format
- convert_
package_ to_ jdk_ metadata - Convert an API package to JDK metadata
- fetch_
and_ cache_ distribution - Fetch metadata for a specific distribution and update the cache
- fetch_
and_ cache_ metadata_ with_ progress - Fetch metadata from API and cache it with progress reporting
- fetch_
package_ checksum - Fetch checksum for a specific JDK package (uses SilentProgress internally)
- get_
metadata - Get metadata with optional version check Get metadata with optional version check (uses SilentProgress internally)
- load_
cache - Load metadata cache from a file
- parse_
architecture_ from_ filename - Parse architecture from filename patterns
- save_
cache - Save metadata cache to a file